@@ -20,8 +20,8 @@
 
 #include "kauthorized.h"
 
-#include <QtCore/QDir>
-#include <QtCore/QRegExp>
+#include <QDir>
+#include <QRegExp>
 #include <QList>
 #include <QUrl>
 
@@ -46,12 +46,12 @@ public:
 #define checkExactMatch(s, b) \
     if (s.isEmpty()) b = true; \
     else if (s[s.length()-1] == QLatin1Char('!')) \
-    { b = false; s.truncate(s.length()-1); } \
+    { b = false; s.chop(1); } \
     else b = true;
 #define checkStartWildCard(s, b) \
     if (s.isEmpty()) b = true; \
     else if (s[0] == QLatin1Char('*')) \
-    { b = true; s = s.mid(1); } \
+    { b = true; s.remove(0, 1); } \
     else b = false;
 #define checkEqual(s, b) \
     b = (s == QLatin1String("="));
@@ -229,7 +229,7 @@ bool KAuthorized::authorizeAction(const QString &action)
     return authorize(QLatin1String("action/") + action);
 }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 24)
 bool KAuthorized::authorizeKAction(const QString &action)
 {
     return authorizeAction(action);
@@ -391,7 +391,7 @@ KCONFIGCORE_EXPORT bool authorizeUrlActionInternal(const QString &action, const
     QUrl destURL(_destURL);
     destURL.setPath(QDir::cleanPath(destURL.path()));
 
-    Q_FOREACH (const URLActionRule &rule, d->urlActionRestrictions) {
+    for (const URLActionRule &rule : qAsConst(d->urlActionRestrictions)) {
         if ((result != rule.permission) && // No need to check if it doesn't make a difference
                 (action == QLatin1String(rule.action.constData())) &&
                 rule.baseMatch(baseURL, baseClass) &&
